/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "XMLHttpRequestProgressEvent.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomProgressEvent.h"
#include "gdom/GdomXMLHttpRequestProgressEvent.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomProgressEvent.h"
#include "gdom/PrivateGdomXMLHttpRequestProgressEvent.h"
#include "gdom/PrivateIntGdomXMLHttpRequestProgressEvent.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMXMLHttpRequestProgressEvent::GDOMXMLHttpRequestProgressEvent(PassRefPtr<WebCore::XMLHttpRequestProgressEvent> impl)
    : GDOMProgressEvent(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "XMLHttpRequestProgressEvent.h"
#include <gdom/GdomXMLHttpRequestProgressEvent.h>
#include <gdom/PrivateGdomXMLHttpRequestProgressEvent.h>
#include <gdom/PrivateIntGdomXMLHttpRequestProgressEvent.h>
#include <gdom/GdomXMLHttpRequestProgressEventprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomXMLHttpRequestProgressEvent, gdom_xml_http_request_progress_event, GDOM_TYPE_PROGRESS_EVENT);

/*
struct _GdomXMLHttpRequestProgressEventPrivate {
    class WebCore::XMLHttpRequestProgressEvent *item;
};

#define GDOM_XML_HTTP_REQUEST_PROGRESS_EVENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_XML_HTTP_REQUEST_PROGRESS_EVENT, GdomXMLHttpRequestProgressEventPrivate))
*/
G_END_DECLS
WebCore::XMLHttpRequestProgressEvent *
gdom_xml_http_request_progress_event_get_private(GdomXMLHttpRequestProgressEvent *request)
{
    GDOMXMLHttpRequestProgressEvent *res;
    res = static_cast<GDOMXMLHttpRequestProgressEvent*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::XMLHttpRequestProgressEvent*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_POSITION,
    PROP_TOTAL_SIZE,
};


static void gdom_xml_http_request_progress_event_finalize(GObject* object)
{
    /*GdomXMLHttpRequestProgressEvent* request = GDOM_XML_HTTP_REQUEST_PROGRESS_EVENT(object);*/
    /*GdomXMLHttpRequestProgressEventPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_PROGRESS_EVENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_xml_http_request_progress_event_parent_class)->finalize(object);
}

static void gdom_xml_http_request_progress_event__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomXMLHttpRequestProgressEvent *self = GDOM_XML_HTTP_REQUEST_PROGRESS_EVENT(object);
    WebCore::XMLHttpRequestProgressEvent * gself = (gdom_xml_http_request_progress_event_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_xml_http_request_progress_event__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomXMLHttpRequestProgressEvent *self = GDOM_XML_HTTP_REQUEST_PROGRESS_EVENT(object);
    WebCore::XMLHttpRequestProgressEvent * gself = (gdom_xml_http_request_progress_event_get_private(self));
    switch (prop_id) {
    case PROP_POSITION:
    {
         g_value_set_ulong (value, gself->position());
         break;
    }
    case PROP_TOTAL_SIZE:
    {
         g_value_set_ulong (value, gself->totalSize());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_xml_http_request_progress_event_class_init(GdomXMLHttpRequestProgressEventClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_xml_http_request_progress_event_finalize;
    g_klass->set_property = gdom_xml_http_request_progress_event__set_property_fn;
    g_klass->get_property = gdom_xml_http_request_progress_event__get_property_fn;

    g_object_class_install_property (g_klass, PROP_POSITION,
            g_param_spec_ulong ("position", /* name */
                "xml_http_request_progress_event_position", /* short description */
                "read-only  gulong XMLHttpRequestProgressEvent.position", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_TOTAL_SIZE,
            g_param_spec_ulong ("total_size", /* name */
                "xml_http_request_progress_event_total_size", /* short description */
                "read-only  gulong XMLHttpRequestProgressEvent.total_size", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomXMLHttpRequestProgressEventPrivate));*/
}

static void gdom_xml_http_request_progress_event_init(GdomXMLHttpRequestProgressEvent* request)
{
    /*GdomXMLHttpRequestProgressEventPrivate* priv = GDOM_XML_HTTP_REQUEST_PROGRESS_EVENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

